import { Angle, Length } from 'unitsnet-js';
import { GeoCurve } from './models/geo-curve';
import { GeoPoint } from './models/geo-point';
/**
 * A Geo location in the world, allows easily API to the geo-calculation.
 */
export declare class GeoLocation {
    geoCoordinates: GeoPoint;
    /**
     * The location latitude.
     */
    get Latitude(): Angle;
    /**
     * The location longitude.
     */
    get Longitude(): Angle;
    /**
     * Create a new GeoLocation instance
     * @param geoCoordinates The position coordinates in the world.
     */
    constructor(geoCoordinates: GeoPoint);
    /**
     * Get the curve (range) between current location and the given location
     * @param geoLocation The location to calculate the curve to.
     * @returns The curve info.
     */
    curve(geoLocation: GeoLocation): GeoCurve;
    /**
     * Get distinction from current location by direction and distance.
     * @param heading The distention direction angle.
     * @param distance The destination distance from current location.
     * @returns The destination location.
     */
    destination(heading: Angle, distance: Length): GeoLocation;
    /**
     * Get the distance from current location to the given location.
     * @param geoLocation The location to get the distance from.
     * @returns The distance between th locations.
     */
    distance(geoLocation: GeoLocation): Length;
}
//# sourceMappingURL=geo-location.d.ts.map