"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GeoLocation = void 0;
const geodetic_calculations_1 = require("./geodetic-calculations");
/**
 * A Geo location in the world, allows easily API to the geo-calculation.
 */
class GeoLocation {
    /**
     * Create a new GeoLocation instance
     * @param geoCoordinates The position coordinates in the world.
     */
    constructor(geoCoordinates) {
        this.geoCoordinates = geoCoordinates;
    }
    /**
     * The location latitude.
     */
    get Latitude() {
        return this.geoCoordinates.Latitude;
    }
    /**
     * The location longitude.
     */
    get Longitude() {
        return this.geoCoordinates.Longitude;
    }
    /**
     * Get the curve (range) between current location and the given location
     * @param geoLocation The location to calculate the curve to.
     * @returns The curve info.
     */
    curve(geoLocation) {
        return geodetic_calculations_1.getGeoPointsCurve(this.geoCoordinates, geoLocation.geoCoordinates);
    }
    /**
     * Get distinction from current location by direction and distance.
     * @param heading The distention direction angle.
     * @param distance The destination distance from current location.
     * @returns The destination location.
     */
    destination(heading, distance) {
        return new GeoLocation(geodetic_calculations_1.getDestinationGeoPoint(this.geoCoordinates, heading, distance));
    }
    /**
     * Get the distance from current location to the given location.
     * @param geoLocation The location to get the distance from.
     * @returns The distance between th locations.
     */
    distance(geoLocation) {
        return geodetic_calculations_1.getDistance(this.geoCoordinates, geoLocation.geoCoordinates);
    }
}
exports.GeoLocation = GeoLocation;
//# sourceMappingURL=geo-location.js.map