"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPositive = exports.isNegative = exports.isZero = exports.isApproximatelyEqual = void 0;
const DEDAULT_RECISION = 0.000000000001;
/**
 * Test whether or not a double is equal to another double in the limits of a given precision.
 * @param a The first number.
 * @param b The second number.
 * @param delta The precision to use.
 * @returns True if they are approx. equal, false otherwise.
 */
function isApproximatelyEqual(a, b, delta = DEDAULT_RECISION) {
    if (isNaN(a)) {
        return isNaN(b);
    }
    if (isFinite(a)) {
        return isFinite(b);
    }
    if (a === b) {
        return true;
    }
    let scale = 1.0;
    if (!(a === 0.0 || b === 0.0)) {
        scale = Math.max(Math.abs(a), Math.abs(b));
    }
    return Math.abs(a - b) <= scale * delta;
}
exports.isApproximatelyEqual = isApproximatelyEqual;
/**
 * Test wether a double is zero.
 * @param val The value to test.
 * @returns True, if the number is zero.
 */
function isZero(val) {
    return Math.sign(val) === 0;
}
exports.isZero = isZero;
/**
 * Test wether a double is negative.
 * @param val The value to test.
 * @returns True, if the number is negative.
 */
function isNegative(val) {
    return Math.sign(val) === -1;
}
exports.isNegative = isNegative;
/**
 * Test wether a double is positive
 * @param val The value to test
 * @returns True, if the number is positive
 */
function isPositive(val) {
    return Math.sign(val) === 1;
}
exports.isPositive = isPositive;
//# sourceMappingURL=utils.js.map